@@ -15,7 +15,10 @@
 // along with subxt.  If not, see <http://www.gnu.org/licenses/>.
 
 use crate::types::TypeGenerator;
-use frame_metadata::PalletConstantMetadata;
+use frame_metadata::{
+    PalletConstantMetadata,
+    PalletMetadata,
+};
 use heck::ToSnakeCase as _;
 use proc_macro2::TokenStream as TokenStream2;
 use quote::{
@@ -26,18 +29,22 @@ use scale_info::form::PortableForm;
 
 pub fn generate_constants(
     type_gen: &TypeGenerator,
+    pallet: &PalletMetadata<PortableForm>,
     constants: &[PalletConstantMetadata<PortableForm>],
     types_mod_ident: &syn::Ident,
 ) -> TokenStream2 {
     let constant_fns = constants.iter().map(|constant| {
         let fn_name = format_ident!("{}", constant.name.to_snake_case());
+        let pallet_name = &pallet.name;
+        let constant_name = &constant.name;
         let return_ty = type_gen.resolve_type_path(constant.ty.id(), &[]);
 
-        let ref_slice = constant.value.as_slice();
-
         quote! {
             pub fn #fn_name(&self) -> ::core::result::Result<#return_ty, ::subxt::BasicError> {
-                Ok(::subxt::codec::Decode::decode(&mut &[#(#ref_slice,)*][..])?)
+                let pallet = self.client.metadata().pallet(#pallet_name)?;
+                let constant = pallet.constant(#constant_name)?;
+                let value = ::subxt::codec::Decode::decode(&mut &constant.value[..])?;
+                Ok(value)
             }
         }
     });
@@ -46,9 +53,15 @@ pub fn generate_constants(
         pub mod constants {
             use super::#types_mod_ident;
 
-            pub struct ConstantsApi;
+            pub struct ConstantsApi<'a, T: ::subxt::Config> {
+                client: &'a ::subxt::Client<T>,
+            }
+
+            impl<'a, T: ::subxt::Config> ConstantsApi<'a, T> {
+                pub fn new(client: &'a ::subxt::Client<T>) -> Self {
+                    Self { client }
+                }
 
-            impl ConstantsApi {
                 #(#constant_fns)*
             }
         }
