@@ -203,6 +203,7 @@ impl RuntimeGenerator {
             let constants_mod = if !pallet.constants.is_empty() {
                 constants::generate_constants(
                     &type_gen,
+                    pallet,
                     &pallet.constants,
                     types_mod_ident,
                 )
@@ -288,7 +289,7 @@ impl RuntimeGenerator {
                 impl<T, X> ::core::convert::From<::subxt::Client<T>> for RuntimeApi<T, X>
                 where
                     T: ::subxt::Config,
-                    X: ::subxt::SignedExtra<T>
+                    X: ::subxt::extrinsic::ExtrinsicParams<T>
                 {
                     fn from(client: ::subxt::Client<T>) -> Self {
                         Self { client, marker: ::core::marker::PhantomData }
@@ -298,10 +299,10 @@ impl RuntimeGenerator {
                 impl<'a, T, X> RuntimeApi<T, X>
                 where
                     T: ::subxt::Config,
-                    X: ::subxt::SignedExtra<T>,
+                    X: ::subxt::extrinsic::ExtrinsicParams<T>,
                 {
-                    pub fn constants(&'a self) -> ConstantsApi {
-                        ConstantsApi
+                    pub fn constants(&'a self) -> ConstantsApi<'a, T> {
+                        ConstantsApi { client: &self.client }
                     }
 
                     pub fn storage(&'a self) -> StorageApi<'a, T> {
@@ -335,12 +336,14 @@ impl RuntimeGenerator {
                     }
                 }
 
-                pub struct ConstantsApi;
+                pub struct ConstantsApi<'a, T: ::subxt::Config> {
+                    client: &'a ::subxt::Client<T>,
+                }
 
-                impl ConstantsApi {
+                impl<'a, T: ::subxt::Config> ConstantsApi<'a, T> {
                     #(
-                        pub fn #pallets_with_constants(&self) -> #pallets_with_constants::constants::ConstantsApi {
-                            #pallets_with_constants::constants::ConstantsApi
+                        pub fn #pallets_with_constants(&self) -> #pallets_with_constants::constants::ConstantsApi<'a, T> {
+                            #pallets_with_constants::constants::ConstantsApi::new(self.client)
                         }
                     )*
                 }
@@ -368,7 +371,7 @@ impl RuntimeGenerator {
                 impl<'a, T, X> TransactionApi<'a, T, X>
                 where
                     T: ::subxt::Config,
-                    X: ::subxt::SignedExtra<T>,
+                    X: ::subxt::extrinsic::ExtrinsicParams<T>,
                 {
                     #(
                         pub fn #pallets_with_calls(&self) -> #pallets_with_calls::calls::TransactionApi<'a, T, X> {
